import { reactive } from "vue";
import { ElMessage, ElMessageBox, getGroupUrl, http } from "./importUsed";

let UrlList = reactive(null);
// 新增
interface addType {
  module: string;
  method: string;
  params: object;
}
const requestAdd = async (row: addType, callback?: Function) => {
  UrlList = await getGroupUrl();
  const { status, msg }: any = await http.Request({
    method: UrlList[row.module][row.method].method,
    url: UrlList[row.module][row.method].url,
    params: row.params
  });
  if (status === 1) {
    //业务成功回调
    ElMessage({
      message: "新增成功",
      type: "success"
    });
    // 关闭修改弹窗;
    callback();
  } else {
    //业务失败回调
    ElMessageBox.alert(msg, "提示", {
      confirmButtonText: "关闭",
      type: "warning"
    });
  }
};
// 删除
interface deleteType {
  module: string;
  method: string;
  msg: string;
  id: number | string;
}
const requestDelete = async (row: deleteType, callback: Function) => {
  UrlList = await getGroupUrl();
  ElMessageBox.confirm(row.msg || "是否删除该项", "提示", {
    confirmButtonText: "删除",
    cancelButtonText: "取消",
    type: "warning"
  }).then(async () => {
    const { status, msg }: any = await http.Request({
      method: UrlList[row.module][row.method].method,
      url: UrlList[row.module][row.method].url,
      params: row.id
    });
    if (status === 1) {
      ElMessage({
        message: "删除成功",
        type: "success"
      });
      callback();
    } else {
      ElMessageBox.alert(msg, "提示", {
        confirmButtonText: "关闭",
        type: "warning"
      });
    }
  });
};
// 修改
interface editType {
  module: string;
  method: string;
  params: object;
}
const requestEdit = async (row: editType, callback: Function) => {
  UrlList = await getGroupUrl();
  const { status, msg }: any = await http.Request({
    method: UrlList[row.module][row.method].method,
    url: UrlList[row.module][row.method].url,
    params: row.params
  });
  if (status === 1) {
    //业务成功回调
    ElMessage({
      message: "修改成功",
      type: "success"
    });
    // 关闭修改弹窗;
    callback();
  } else {
    //业务失败回调
    ElMessageBox.alert(msg, "提示", {
      confirmButtonText: "关闭",
      type: "warning"
    });
  }
};
// 查询
interface searchType {
  module: string;
  method: string;
  params: object;
  pageSize?: number;
  pageNum?: number;
}
const requestSearch = async (row: searchType) => {
  UrlList = await getGroupUrl();
  const { status, msg, data }: any = await http.Request({
    method: UrlList[row.module][row.method].method,
    url: UrlList[row.module][row.method].url,
    params: {
      ...row.params,
      pageSize: row.pageSize,
      pageNum: row.pageNum
    }
  });
  return { status, msg, data };
};
export { requestAdd, requestDelete, requestEdit, requestSearch };
